==> qmmp-plugin-pack-1.5.0.tar.bz2: qmmp-plugin-pack-1.5.0/src/Transports/ytb/translations/ytb_plugin_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>YtbInputFactory</name>
    <message>
        <location filename="../ytbinputfactory.cpp" line="36"/>
        <source>Youtube Plugin</source>
        <translation>Módulo Youtube</translation>
    </message>
    <message>
        <location filename="../ytbinputfactory.cpp" line="60"/>
        <source>not found</source>
        <translation>no encontrado</translation>
    </message>
    <message>
        <location filename="../ytbinputfactory.cpp" line="62"/>
        <source>About Youtube Transport Plugin</source>
        <translation>Acerca del Módulo de Transporte Youtube</translation>
    </message>
    <message>
        <location filename="../ytbinputfactory.cpp" line="63"/>
        <source>Qmmp Youtube Transport Plugin</source>
        <translation>Módulo de Transporte Youtube de Qmmp</translation>
    </message>
    <message>
        <location filename="../ytbinputfactory.cpp" line="64"/>
        <source>This plugin adds feature to play audio from Youtube using &lt;a href=&quot;https://youtube-dl.org/&quot;&gt;youtube-dl&lt;/a&gt; utility</source>
        <translation>Este módulo añade funciones para reproducir audio desde Youtube utilizando la utilidad &lt;a href=&quot;https://youtube-dl.org/&quot;&gt;youtube-dl&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../ytbinputfactory.cpp" line="66"/>
        <source>youtube-dl version: %1</source>
        <translation>Versión de youtube-dl: %1</translation>
    </message>
    <message>
        <location filename="../ytbinputfactory.cpp" line="67"/>
        <source>Written by: Ilya Kotov &amp;lt;forkotov02@ya.ru&amp;gt;</source>
        <translation>Escrito por: Ilya Kotov &amp;lt;forkotov02@ya.ru&amp;gt;</translation>
    </message>
</context>
<context>
    <name>YtbInputSource</name>
    <message>
        <location filename="../ytbinputsource.cpp" line="154"/>
        <source>Uploader</source>
        <translation>Subido por</translation>
    </message>
    <message>
        <location filename="../ytbinputsource.cpp" line="155"/>
        <source>Upload date</source>
        <translation>Fecha de subida</translation>
    </message>
    <message>
        <location filename="../ytbinputsource.cpp" line="156"/>
        <source>Duration</source>
        <translation>Duración</translation>
    </message>
</context>
</TS>

==> qmmp-plugin-pack-1.5.3.tar.bz2: qmmp-plugin-pack-1.5.3/src/Transports/ytb/translations/ytb_plugin_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>YtbInputFactory</name>
    <message>
        <location filename="../ytbinputfactory.cpp" line="36"/>
        <source>Youtube Plugin</source>
        <translation>Módulo Youtube</translation>
    </message>
    <message>
        <location filename="../ytbinputfactory.cpp" line="69"/>
        <source>About Youtube Transport Plugin</source>
        <translation>Acerca del Módulo de Transporte Youtube</translation>
    </message>
    <message>
        <location filename="../ytbinputfactory.cpp" line="70"/>
        <source>Qmmp Youtube Transport Plugin</source>
        <translation>Módulo de Transporte Youtube de Qmmp</translation>
    </message>
    <message>
        <location filename="../ytbinputfactory.cpp" line="71"/>
        <source>This plugin adds feature to play audio from Youtube using %1 utility</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ytbinputfactory.cpp" line="73"/>
        <source>%1 version: %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ytbinputfactory.cpp" line="74"/>
        <source>Written by: Ilya Kotov &amp;lt;forkotov02@ya.ru&amp;gt;</source>
        <translation>Escrito por: Ilya Kotov &amp;lt;forkotov02@ya.ru&amp;gt;</translation>
    </message>
</context>
<context>
    <name>YtbInputSource</name>
    <message>
        <location filename="../ytbinputsource.cpp" line="184"/>
        <source>Uploader</source>
        <translation>Subido por</translation>
    </message>
    <message>
        <location filename="../ytbinputsource.cpp" line="185"/>
        <source>Upload date</source>
        <translation>Fecha de subida</translation>
    </message>
    <message>
        <location filename="../ytbinputsource.cpp" line="186"/>
        <source>Duration</source>
        <translation>Duración</translation>
    </message>
</context>
</TS>
